@@ -30,7 +30,7 @@ import os
 from dotenv import load_dotenv
 
 # Read in .env file if it exists locally, else look to env vars
-load_dotenv(verbose=True)
+load_dotenv(verbose=False)
 
 NUTRA_DIR = os.path.join(os.path.expanduser("~"), ".nutra")
 
@@ -40,8 +40,23 @@ SERVER_HOST = os.getenv("NUTRA_OVERRIDE_LOCAL_SERVER_HOST", REMOTE_HOST)
 
 TESTING = SERVER_HOST != REMOTE_HOST
 
+# ------------------------
+# Nutrient IDs
+# ------------------------
 NUTR_ID_KCAL = 208
 
+NUTR_ID_PROTEIN = 203
+
+NUTR_ID_CARBS = 205
+NUTR_ID_SUGAR = 269
+NUTR_ID_FIBER = 291
+
+NUTR_ID_FAT_TOT = 204
+NUTR_ID_FAT_SAT = 606
+NUTR_ID_FAT_MONO = 645
+NUTR_ID_FAT_POLY = 646
+
+
 NUTR_IDS_FLAVONES = [
     710,
     711,
